FrameDeallocator

Trait FrameDeallocator 

pub trait FrameDeallocator<S: PageSize> {
    // Required method
    unsafe fn deallocate_frame(&mut self, frame: PhysFrame<S>);
}
A trait for types that can deallocate a frame of memory.

Required Methods

unsafe fn deallocate_frame(&mut self, frame: PhysFrame<S>)

Deallocate the given unused frame.

Safety

The caller must ensure that the passed frame is unused.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors